@@ -27,7 +27,7 @@ ext_modules = [
         sources=["pyxcp/recorder/lz4.cpp", "pyxcp/recorder/wrap.cpp"],
         define_macros=[("EXTENSION_NAME", EXT_NAMES[0]), ("NDEBUG", 1)],
         optional=False,
-        cxx_std="17",
+        cxx_std=20,  # Extension will use C++20 generators/coroutines.
     ),
 ]
 
