@@ -9,14 +9,17 @@
 
 #include <array>
 #include <atomic>
+#include <exception>
+#include <coroutine>
 #include <functional>
 #include <optional>
 #include <condition_variable>
 #include <mutex>
 #include <queue>
-
+#include <utility>
 #include <string>
 #include <stdexcept>
+
 #include <cerrno>
 #include <cstdint>
 #include <cstring>
@@ -26,6 +29,8 @@
 #include <thread>
 #include <vector>
 
+//#include "coro/mcnellis_generator.h"
+
 #if defined(_WIN32)
     #include <io.h>
     #include <fcntl.h>
@@ -136,6 +141,68 @@ enum class FrameCategory : std::uint8_t {
 };
 
 
+template<class T>
+struct generator {
+    struct promise_type {
+        T current_value_;
+        auto yield_value(T value) {
+            this->current_value_ = value;
+            return std::suspend_always{};
+        }
+        auto initial_suspend() { return std::suspend_always{}; }
+        auto final_suspend() noexcept { return std::suspend_always{}; }
+        generator get_return_object() { return generator{ this }; };
+        void unhandled_exception() { std::terminate(); }
+        void return_void() {}
+    };
+
+    using handle_t = std::coroutine_handle<promise_type>;
+
+    struct iterator {
+        handle_t coro_;
+        bool done_;
+
+        iterator() : done_(true) {}
+
+        explicit iterator(handle_t coro, bool done)
+            : coro_(coro), done_(done) {}
+
+        iterator& operator++() {
+            coro_.resume();
+            done_ = coro_.done();
+            return *this;
+        }
+
+        bool operator==(const iterator& rhs) const { return done_ == rhs.done_; }
+        bool operator!=(const iterator& rhs) const { return !(*this == rhs); }
+        const T& operator*() const { return coro_.promise().current_value_; }
+        const T* operator->() const { return &*(*this); }
+    };
+
+    iterator begin() {
+        coro_.resume();
+        return iterator(coro_, coro_.done());
+    }
+
+    iterator end() { return iterator(); }
+
+    generator(const generator&) = delete;
+    generator(generator&& rhs) : coro_(std::exchange(rhs.coro_, nullptr)) {}
+
+    ~generator() {
+        if (coro_) {
+            coro_.destroy();
+        }
+    }
+
+private:
+    explicit generator(promise_type* p)
+        : coro_(handle_t::from_promise(*p)) {}
+
+    handle_t coro_;
+};
+
+
 namespace detail
 {
     const std::string FILE_EXTENSION(".xmraw");
@@ -164,11 +231,9 @@ const auto round_to_alignment = create_rounding_func(__ALIGNMENT_REQUIREMENT);
 
 inline void _fcopy(blob_t * dest, const blob_t * src, std::size_t n)
 {
-    printf("before _fcopy\n");
     for (std::size_t i = 0; i < n; ++i) {
         dest[i] = src[i];
     }
-    printf("after _fcopy\n");
 }
 
 #if STANDALONE_REKORDER == 1
@@ -211,7 +276,7 @@ class TsQueue {
 public:
     explicit  TsQueue() {}
 
-    TsQueue(const TsQueue& other) {
+    TsQueue(const TsQueue& other) : m_mtx{}, m_cond{} {
         std::lock_guard<std::mutex> lock(other.m_mtx);
         m_queue = other.m_queue;
     }
@@ -244,7 +309,7 @@ private:
 
 class Event {
 public:
-     explicit Event() : m_mtx{}, m_flag{false}, m_cond{} {}
+    explicit Event() {}
 
     Event(const Event& other) {
         std::lock_guard<std::mutex> lock(other.m_mtx);
@@ -269,9 +334,9 @@ public:
     }
 
 private:
-    mutable std::mutex m_mtx;
+    mutable std::mutex m_mtx {};
     bool m_flag {false};
-    std::condition_variable m_cond;
+    std::condition_variable m_cond {};
 };
 
 
@@ -284,7 +349,7 @@ public:
     {
         m_file_name = file_name + detail::FILE_EXTENSION;
 #if defined(_WIN32)
-        m_fd = CreateFile(
+        m_fd = CreateFileA(
             m_file_name.c_str(),
             GENERIC_READ | GENERIC_WRITE,
             0,
@@ -293,9 +358,11 @@ public:
             FILE_ATTRIBUTE_NORMAL | FILE_FLAG_RANDOM_ACCESS,
             NULL
         );
-        printf("m_fd: %d\n", m_fd);
+        //printf("CreateFile returned: %u\n", GetLastError());
 #else
         m_fd = open(m_file_name.c_str(), O_CREAT | O_RDWR | O_TRUNC, 0666);
+
+        printf("open returned: %u\n", errno);
 #endif
         truncate(megabytes(prealloc));
         m_mmap = new mio::mmap_sink(m_fd);
@@ -461,57 +528,52 @@ public:
         }
 
         m_offset += detail::FILE_HEADER_SIZE;
-        printf("leaving c-tor\n");
     }
 
-    const FileHeaderType get_header() const {
-
+    const FileHeaderType get_header()  const noexcept  {
         return m_header;
     }
 
-    void reset() {
-        m_current_container = 0;
-        m_offset = file_header_size();
-    }
-
-
-    std::optional<FrameVector> next_block() {
+    generator<FrameTuple> next_record() /*noexcept */ {
         auto container = ContainerHeaderType{};
         auto total = 0;
         auto frame = frame_header_t{};
         size_t boffs = 0;
         auto result = FrameVector{};
         payload_t payload;
+        uint32_t current_container{ 0 };
 
-        if (m_current_container >= m_header.num_containers) {
-            return std::nullopt;
-        }
-        read_bytes(m_offset, detail::CONTAINER_SIZE, reinterpret_cast<blob_t*>(&container));
-        //printf("rc: %d c: %d u: %d \n", container.record_count, container.size_compressed, container.size_uncompressed);
+        while (true) {
+            if (current_container >= m_header.num_containers) {
+                co_return;
+            }
+            read_bytes(m_offset, detail::CONTAINER_SIZE, reinterpret_cast<blob_t*>(&container));
+            //printf("rc: %d c: %d u: %d \n", container.record_count, container.size_compressed, container.size_uncompressed);
 
-        __ALIGN auto buffer = new blob_t[container.size_uncompressed];
+            __ALIGN auto buffer = new blob_t[container.size_uncompressed];
 
-        m_offset += detail::CONTAINER_SIZE;
-        total += container.record_count;
-        result.reserve(container.record_count);
-        const int uc_size = ::LZ4_decompress_safe(ptr(m_offset), buffer, container.size_compressed, container.size_uncompressed);
-        if (uc_size < 0) {
-            throw std::runtime_error("LZ4 decompression failed.");
+            m_offset += detail::CONTAINER_SIZE;
+            total += container.record_count;
+            result.reserve(container.record_count);
+            const int uc_size = ::LZ4_decompress_safe(ptr(m_offset), buffer, container.size_compressed, container.size_uncompressed);
+            if (uc_size < 0) {
+                throw std::runtime_error("LZ4 decompression failed.");
+            }
+            boffs = 0;
+            for (std::uint32_t idx = 0; idx < container.record_count; ++idx) {
+                _fcopy((blob_t*)&frame, &(buffer[boffs]), sizeof(frame_header_t));
+                boffs += sizeof(frame_header_t);
+                //result.emplace_back(std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, create_payload(frame.length, &buffer[boffs])));
+                co_yield std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, create_payload(frame.length, &buffer[boffs]));
+                boffs += frame.length;
+                //result.emplace_back(std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, std::move(payload)));
+            }
+            m_offset += container.size_compressed;
+            current_container += 1;
+            delete[] buffer;
         }
-        boffs = 0;
-        for (std::uint32_t idx = 0; idx < container.record_count; ++idx) {
-            _fcopy((blob_t*)&frame, &(buffer[boffs]), sizeof(frame_header_t));
-            boffs += sizeof(frame_header_t);
-            //result.emplace_back(std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, create_payload(frame.length, &buffer[boffs])));
-            result.push_back(std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, create_payload(frame.length, &buffer[boffs])));
-            boffs += frame.length;
-            //result.emplace_back(std::make_tuple(frame.category, frame.counter, frame.timestamp, frame.length, std::move(payload)));
-        }
-        m_offset += container.size_compressed;
-        m_current_container += 1;
-        delete[] buffer;
         //printf("OK, retuning from next -- Total: %u\n", total);
-        return std::optional<FrameVector>{result};
+        //return std::optional<FrameVector>{result};
     }
 
     ~XcpLogFileReader()
@@ -557,7 +619,6 @@ protected:
 private:
     std::string m_file_name;
     std::size_t m_offset{0};
-    std::size_t m_current_container{0};
     mio::mmap_source * m_mmap{nullptr};
     //FileHeaderType m_header{0, 0, 0, 0, 0, 0, 0};
     FileHeaderType m_header;
