@@ -24,7 +24,6 @@ public:
             (double)hdr.size_uncompressed / (double)hdr.size_compressed
         );
     }
-
 };
 
 class _PyXcpLogFileWriter : public XcpLogFileWriter {
@@ -37,10 +36,14 @@ PYBIND11_MODULE(rekorder, m) {
     m.doc() = "XCP raw frame recorder.";
     py::class_<_PyXcpLogFileReader>(m, "_PyXcpLogFileReader")
         .def(py::init<const std::string &>())
-        //.def("next_block",  &_PyXcpLogFileReader::next, py::return_value_policy::move)
-        .def("next",  &_PyXcpLogFileReader::next_block, py::return_value_policy::reference)
-        .def("get_header",  &_PyXcpLogFileReader::py_get_header)
-        .def("reset",  &_PyXcpLogFileReader::reset)
+        .def("next_record", &_PyXcpLogFileReader::next_record) //, py::return_value_policy::reference)
+        .def("get_header", &_PyXcpLogFileReader::get_header)
+#if 0
+        .def("__iter__", [](std::vector<int>& v) {
+            return py::make_iterator(v.begin(), v.end());
+            }, py::keep_alive<0, 1>()
+        )
+#endif
     ;
     py::class_<_PyXcpLogFileWriter>(m, "_PyXcpLogFileWriter")
         .def(py::init<const std::string&, std::uint32_t, std::uint32_t>())
