@@ -1,37 +1,16 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
-__copyright__ = """
-    pySART - Simplified AUTOSAR-Toolkit for Python.
-
-   (C) 2009-2019 by Christoph Schueler <cpu12.gems@googlemail.com>
-
-   All Rights Reserved
-
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-"""
+import struct
+import threading
+from array import array
+from collections import deque
+from pyxcp.transport.base import BaseTransport
+from time import perf_counter
+from time import sleep
+from time import time
 
 import usb.core
 import usb.util
-import struct
-from time import perf_counter, sleep, time
-from array import array
-from collections import deque
-import threading
-
-from pyxcp.transport.base import BaseTransport
 
 RECV_SIZE = 4096
 
@@ -115,7 +94,7 @@ class Usb(BaseTransport):
 
         close_event_set = self.closeEvent.isSet
 
-        high_resolution_time = self.perf_counter_origin > 0
+        high_resolution_time = self.perf_counter_origin < 0
         timestamp_origin = self.timestamp_origin
         perf_counter_origin = self.perf_counter_origin
 
@@ -136,9 +115,9 @@ class Usb(BaseTransport):
                         recv_timestamp = timestamp_origin + perf_counter() - perf_counter_origin
                     read_count = read(buffer, 10)  # 10ms timeout
                     if read_count != RECV_SIZE:
-                        _packets.append((bytes(buffer)[:read_count], recv_timestamp))
+                        _packets.append((buffer.tobytes()[:read_count], recv_timestamp))
                     else:
-                        _packets.append((bytes(buffer), recv_timestamp))
+                        _packets.append((buffer.tobytes(), recv_timestamp))
                 except BaseException:
                     # print(format_exc())
                     sleep(0.001)
@@ -204,7 +183,7 @@ class Usb(BaseTransport):
                             break
 
     def send(self, frame):
-        if self.perf_counter_origin > 0:
+        if self.perf_counter_origin < 0:
             self.pre_send_timestamp = time()
             try:
                 self.command_endpoint.write(frame)
